Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var DefaultOptions = Options{}
DefaultOptions is a quic service configuration that will be used if no options provided.
Functions ¶
func ParseJSONOptions ¶
func ParseJSONOptions(request *json.RawMessage) (service.Options, error)
ParseJSONOptions function fills in Quic options from JSON request
Types ¶
type ConsumerConfig ¶
type ConsumerConfig struct {
URL string `json:"url"`
}
ConsumerConfig represents configuration for consumer.
type Manager ¶
type Manager struct {
// contains filtered or unexported fields
}
Manager represents an instance of Quic service
func NewManager ¶
NewManager creates new instance of Quic service
func (*Manager) ProvideConfig ¶
func (m *Manager) ProvideConfig(sessionID string, sessionConfig json.RawMessage, remoteConn p2p.ServiceConn) (*service.ConfigParams, error)
ProvideConfig provides the config for consumer and handles new Quic connection.
type Options ¶
type Options struct{}
Options describes options which are required to start Quic service.
func GetOptions ¶
func GetOptions() Options
GetOptions returns effective Quic service options from application configuration.
func (Options) MarshalJSON ¶
MarshalJSON implements json.Marshaler interface to provide human readable configuration.
func (*Options) UnmarshalJSON ¶
UnmarshalJSON implements json.Unmarshaler interface to receive human readable configuration.